@@ -31,7 +31,8 @@ POE::Session->create(
       tick => sub {
          $fg++;
          $fg = 1 if $fg > 7;
-         $static->pen->chattr( fg => $fg );
+         $static->set_style( fg => $fg );
+         $static->redraw;
 
          $_[KERNEL]->delay_set( tick => 0.5 );
       },
